ControllerFeatures

Struct ControllerFeatures 

pub struct ControllerFeatures<'cglue_a, CGlueInst: 'cglue_a, CGlueCtx: ContextBounds>
where ControllerFeaturesContainer<CGlueInst, CGlueCtx>: CGlueObjBase,
{ /* private fields */ }
Trait group potentially implementing Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < > + MouseWriter < > traits.

Optional traits are not implemented here, however. There are numerous conversion functions available for safely retrieving a concrete collection of traits.

check_impl_ functions allow to check if the object implements the wanted traits.

into_impl_ functions consume the object and produce a new final structure that keeps only the required information.

cast_impl_ functions merely check and transform the object into a type that can be transformed back into ControllerFeatures without losing data.

as_ref_, and as_mut_ functions obtain references to safe objects, but do not perform any memory transformations either. They are the safest to use, because there is no risk of accidentally consuming the whole object.

Implementations

Source

impl<'cglue_a, CGlueInst, CGlueCtx: ContextBounds> ControllerFeatures<'cglue_a, CGlueInst, CGlueCtx>
where ControllerFeaturesContainer<CGlueInst, CGlueCtx>: CGlueObjBase,

pub fn enable_clone(self) -> Self
where &'cglue_a CloneVtbl<'cglue_a, ControllerFeaturesContainer<CGlueInst, CGlueCtx>>: Default,

pub fn enable_keyboardwriter(self) -> Self
where &'cglue_a KeyboardWriterVtbl<'cglue_a, ControllerFeaturesContainer<CGlueInst, CGlueCtx>>: Default,

pub fn enable_mousewriter(self) -> Self
where &'cglue_a MouseWriterVtbl<'cglue_a, ControllerFeaturesContainer<CGlueInst, CGlueCtx>>: Default,

Source

impl<'cglue_a, CGlueInst, CGlueCtx: ContextBounds> ControllerFeatures<'cglue_a, CGlueInst, CGlueCtx>
where ControllerFeaturesContainer<CGlueInst, CGlueCtx>: CGlueObjBase, &'cglue_a LoadableVtbl<'cglue_a, ControllerFeaturesContainer<CGlueInst, CGlueCtx>>: 'cglue_a + Default,

pub fn new( instance: CGlueInst, context: CGlueCtx, vtbl_clone: Option<&'cglue_a CloneVtbl<'cglue_a, ControllerFeaturesContainer<CGlueInst, CGlueCtx>>>, vtbl_keyboardwriter: Option<&'cglue_a KeyboardWriterVtbl<'cglue_a, ControllerFeaturesContainer<CGlueInst, CGlueCtx>>>, vtbl_mousewriter: Option<&'cglue_a MouseWriterVtbl<'cglue_a, ControllerFeaturesContainer<CGlueInst, CGlueCtx>>>, ) -> Self
where &'cglue_a LoadableVtbl<'cglue_a, ControllerFeaturesContainer<CGlueInst, CGlueCtx>>: 'cglue_a + Default,

Create new instance of ControllerFeatures.

Source

impl<'cglue_a, CGlueT> ControllerFeatures<'cglue_a, CBox<'cglue_a, CGlueT>, NoContext>

pub fn new_boxed( this: CGlueT, vtbl_clone: Option<&'cglue_a CloneVtbl<'cglue_a, ControllerFeaturesContainer<CBox<'cglue_a, CGlueT>, NoContext>>>, vtbl_keyboardwriter: Option<&'cglue_a KeyboardWriterVtbl<'cglue_a, ControllerFeaturesContainer<CBox<'cglue_a, CGlueT>, NoContext>>>, vtbl_mousewriter: Option<&'cglue_a MouseWriterVtbl<'cglue_a, ControllerFeaturesContainer<CBox<'cglue_a, CGlueT>, NoContext>>>, ) -> Self
where &'cglue_a LoadableVtbl<'cglue_a, ControllerFeaturesContainer<CBox<'cglue_a, CGlueT>, NoContext>>: 'cglue_a + Default,

Create new instance of ControllerFeatures.

instance will be moved onto heap.

Source

impl<'cglue_a, CGlueInst, CGlueCtx: ContextBounds> ControllerFeatures<'cglue_a, CGlueInst, CGlueCtx>
where ControllerFeaturesContainer<CGlueInst, CGlueCtx>: CGlueObjBase,

pub fn check_impl_clone(&self) -> bool
where ControllerFeaturesWithClone<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone,

Check whether ControllerFeatures implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < >.

If this check returns true, it is safe to run consuming conversion operations.

pub fn into_impl_clone(self) -> Option<impl 'cglue_a + Loadable + Clone>
where ControllerFeaturesFinalWithClone<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone,

Retrieve a final ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + :: cglue :: ext :: core :: clone :: Clone < >), if all types are present.

pub fn cast_impl_clone( self, ) -> Option<ControllerFeaturesWithClone<'cglue_a, CGlueInst, CGlueCtx>>
where ControllerFeaturesWithClone<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone,

Retrieve a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + :: cglue :: ext :: core :: clone :: Clone < >), if all types are present. It is possible to cast this type back with the From implementation.

pub fn as_mut_impl_clone<'b>( &'b mut self, ) -> Option<&'b mut (impl 'cglue_a + Loadable + Clone)>
where ControllerFeaturesWithClone<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone,

Retrieve mutable reference to a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < >.

pub fn as_ref_impl_clone<'b>( &'b self, ) -> Option<&'b (impl 'cglue_a + Loadable + Clone)>
where ControllerFeaturesWithClone<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone,

Retrieve immutable reference to a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < >.

pub fn check_impl_keyboardwriter(&self) -> bool
where ControllerFeaturesWithKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter,

Check whether ControllerFeatures implements Loadable < > + KeyboardWriter < >.

If this check returns true, it is safe to run consuming conversion operations.

pub fn into_impl_keyboardwriter( self, ) -> Option<impl 'cglue_a + Loadable + KeyboardWriter>
where ControllerFeaturesFinalWithKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter,

Retrieve a final ControllerFeatures variant that implements Loadable < > + KeyboardWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + KeyboardWriter < >), if all types are present.

pub fn cast_impl_keyboardwriter( self, ) -> Option<ControllerFeaturesWithKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>>
where ControllerFeaturesWithKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter,

Retrieve a concrete ControllerFeatures variant that implements Loadable < > + KeyboardWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + KeyboardWriter < >), if all types are present. It is possible to cast this type back with the From implementation.

pub fn as_mut_impl_keyboardwriter<'b>( &'b mut self, ) -> Option<&'b mut (impl 'cglue_a + Loadable + KeyboardWriter)>
where ControllerFeaturesWithKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter,

Retrieve mutable reference to a concrete ControllerFeatures variant that implements Loadable < > + KeyboardWriter < >.

pub fn as_ref_impl_keyboardwriter<'b>( &'b self, ) -> Option<&'b (impl 'cglue_a + Loadable + KeyboardWriter)>
where ControllerFeaturesWithKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter,

Retrieve immutable reference to a concrete ControllerFeatures variant that implements Loadable < > + KeyboardWriter < >.

pub fn check_impl_mousewriter(&self) -> bool
where ControllerFeaturesWithMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + MouseWriter,

Check whether ControllerFeatures implements Loadable < > + MouseWriter < >.

If this check returns true, it is safe to run consuming conversion operations.

pub fn into_impl_mousewriter( self, ) -> Option<impl 'cglue_a + Loadable + MouseWriter>
where ControllerFeaturesFinalWithMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + MouseWriter,

Retrieve a final ControllerFeatures variant that implements Loadable < > + MouseWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + MouseWriter < >), if all types are present.

pub fn cast_impl_mousewriter( self, ) -> Option<ControllerFeaturesWithMouseWriter<'cglue_a, CGlueInst, CGlueCtx>>
where ControllerFeaturesWithMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + MouseWriter,

Retrieve a concrete ControllerFeatures variant that implements Loadable < > + MouseWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + MouseWriter < >), if all types are present. It is possible to cast this type back with the From implementation.

pub fn as_mut_impl_mousewriter<'b>( &'b mut self, ) -> Option<&'b mut (impl 'cglue_a + Loadable + MouseWriter)>
where ControllerFeaturesWithMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + MouseWriter,

Retrieve mutable reference to a concrete ControllerFeatures variant that implements Loadable < > + MouseWriter < >.

pub fn as_ref_impl_mousewriter<'b>( &'b self, ) -> Option<&'b (impl 'cglue_a + Loadable + MouseWriter)>
where ControllerFeaturesWithMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + MouseWriter,

Retrieve immutable reference to a concrete ControllerFeatures variant that implements Loadable < > + MouseWriter < >.

pub fn check_impl_clone_keyboardwriter(&self) -> bool
where ControllerFeaturesWithCloneKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + KeyboardWriter,

Check whether ControllerFeatures implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < >.

If this check returns true, it is safe to run consuming conversion operations.

pub fn into_impl_clone_keyboardwriter( self, ) -> Option<impl 'cglue_a + Loadable + Clone + KeyboardWriter>
where ControllerFeaturesFinalWithCloneKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + KeyboardWriter,

Retrieve a final ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < >), if all types are present.

pub fn cast_impl_clone_keyboardwriter( self, ) -> Option<ControllerFeaturesWithCloneKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>>
where ControllerFeaturesWithCloneKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + KeyboardWriter,

Retrieve a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < >), if all types are present. It is possible to cast this type back with the From implementation.

pub fn as_mut_impl_clone_keyboardwriter<'b>( &'b mut self, ) -> Option<&'b mut (impl 'cglue_a + Loadable + Clone + KeyboardWriter)>
where ControllerFeaturesWithCloneKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + KeyboardWriter,

Retrieve mutable reference to a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < >.

pub fn as_ref_impl_clone_keyboardwriter<'b>( &'b self, ) -> Option<&'b (impl 'cglue_a + Loadable + Clone + KeyboardWriter)>
where ControllerFeaturesWithCloneKeyboardWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + KeyboardWriter,

Retrieve immutable reference to a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < >.

pub fn check_impl_clone_mousewriter(&self) -> bool
where ControllerFeaturesWithCloneMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + MouseWriter,

Check whether ControllerFeatures implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + MouseWriter < >.

If this check returns true, it is safe to run consuming conversion operations.

pub fn into_impl_clone_mousewriter( self, ) -> Option<impl 'cglue_a + Loadable + Clone + MouseWriter>
where ControllerFeaturesFinalWithCloneMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + MouseWriter,

Retrieve a final ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + MouseWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + MouseWriter < >), if all types are present.

pub fn cast_impl_clone_mousewriter( self, ) -> Option<ControllerFeaturesWithCloneMouseWriter<'cglue_a, CGlueInst, CGlueCtx>>
where ControllerFeaturesWithCloneMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + MouseWriter,

Retrieve a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + MouseWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + MouseWriter < >), if all types are present. It is possible to cast this type back with the From implementation.

pub fn as_mut_impl_clone_mousewriter<'b>( &'b mut self, ) -> Option<&'b mut (impl 'cglue_a + Loadable + Clone + MouseWriter)>
where ControllerFeaturesWithCloneMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + MouseWriter,

Retrieve mutable reference to a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + MouseWriter < >.

pub fn as_ref_impl_clone_mousewriter<'b>( &'b self, ) -> Option<&'b (impl 'cglue_a + Loadable + Clone + MouseWriter)>
where ControllerFeaturesWithCloneMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + MouseWriter,

Retrieve immutable reference to a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + MouseWriter < >.

pub fn check_impl_keyboardwriter_mousewriter(&self) -> bool
where ControllerFeaturesWithKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter + MouseWriter,

Check whether ControllerFeatures implements Loadable < > + KeyboardWriter < > + MouseWriter < >.

If this check returns true, it is safe to run consuming conversion operations.

pub fn into_impl_keyboardwriter_mousewriter( self, ) -> Option<impl 'cglue_a + Loadable + KeyboardWriter + MouseWriter>
where ControllerFeaturesFinalWithKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter + MouseWriter,

Retrieve a final ControllerFeatures variant that implements Loadable < > + KeyboardWriter < > + MouseWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + KeyboardWriter < > + MouseWriter < >), if all types are present.

pub fn cast_impl_keyboardwriter_mousewriter( self, ) -> Option<ControllerFeaturesWithKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>>
where ControllerFeaturesWithKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter + MouseWriter,

Retrieve a concrete ControllerFeatures variant that implements Loadable < > + KeyboardWriter < > + MouseWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + KeyboardWriter < > + MouseWriter < >), if all types are present. It is possible to cast this type back with the From implementation.

pub fn as_mut_impl_keyboardwriter_mousewriter<'b>( &'b mut self, ) -> Option<&'b mut (impl 'cglue_a + Loadable + KeyboardWriter + MouseWriter)>
where ControllerFeaturesWithKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter + MouseWriter,

Retrieve mutable reference to a concrete ControllerFeatures variant that implements Loadable < > + KeyboardWriter < > + MouseWriter < >.

pub fn as_ref_impl_keyboardwriter_mousewriter<'b>( &'b self, ) -> Option<&'b (impl 'cglue_a + Loadable + KeyboardWriter + MouseWriter)>
where ControllerFeaturesWithKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + KeyboardWriter + MouseWriter,

Retrieve immutable reference to a concrete ControllerFeatures variant that implements Loadable < > + KeyboardWriter < > + MouseWriter < >.

pub fn check_impl_clone_keyboardwriter_mousewriter(&self) -> bool
where ControllerFeaturesWithCloneKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + KeyboardWriter + MouseWriter,

Check whether ControllerFeatures implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < > + MouseWriter < >.

If this check returns true, it is safe to run consuming conversion operations.

pub fn into_impl_clone_keyboardwriter_mousewriter( self, ) -> Option<impl 'cglue_a + Loadable + Clone + KeyboardWriter + MouseWriter>

Retrieve a final ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < > + MouseWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < > + MouseWriter < >), if all types are present.

pub fn cast_impl_clone_keyboardwriter_mousewriter( self, ) -> Option<ControllerFeaturesWithCloneKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>>
where ControllerFeaturesWithCloneKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + KeyboardWriter + MouseWriter,

Retrieve a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < > + MouseWriter < >.

This consumes the ControllerFeatures, and outputs Some(impl Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < > + MouseWriter < >), if all types are present. It is possible to cast this type back with the From implementation.

pub fn as_mut_impl_clone_keyboardwriter_mousewriter<'b>( &'b mut self, ) -> Option<&'b mut (impl 'cglue_a + Loadable + Clone + KeyboardWriter + MouseWriter)>
where ControllerFeaturesWithCloneKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + KeyboardWriter + MouseWriter,

Retrieve mutable reference to a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < > + MouseWriter < >.

pub fn as_ref_impl_clone_keyboardwriter_mousewriter<'b>( &'b self, ) -> Option<&'b (impl 'cglue_a + Loadable + Clone + KeyboardWriter + MouseWriter)>
where ControllerFeaturesWithCloneKeyboardWriterMouseWriter<'cglue_a, CGlueInst, CGlueCtx>: 'cglue_a + Loadable + Clone + KeyboardWriter + MouseWriter,

Retrieve immutable reference to a concrete ControllerFeatures variant that implements Loadable < > + :: cglue :: ext :: core :: clone :: Clone < > + KeyboardWriter < > + MouseWriter < >.